.. py:function:: sf_psi_n(n, x [, ret])

    Wrapper for :c:func:`gsl_sf_psi_n`
    c code signature: double gsl_sf_psi_n(const int n, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rd__O`
    
    :param int n: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_psi_1_int(n [, ret])

    Wrapper for :c:func:`gsl_sf_psi_1_int`
    c code signature: double gsl_sf_psi_1_int(const int n)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il__Rd__O`
    
    :param int n: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_complex_psi_e(x, y [, ret, result_im.val, result_im.err, result_re.val, result_re.err])

    Wrapper for :c:func:`gsl_sf_complex_psi_e`
    c code signature: int gsl_sf_complex_psi_e(const double x, const double y, gsl_sf_result* result_re, gsl_sf_result* result_im)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord_rd`
    
    :param double x: positional argument 0
    :param double y: positional argument 1
    :param int ret: positional argument 2
    :param double result_im.val: positional argument 3
    :param double result_im.err: positional argument 4
    :param double result_re.val: positional argument 5
    :param double result_re.err: positional argument 6
    :rtype:  tuple(:param int ret: positional argument 2, :param double result_im.val: positional argument 3, :param double result_im.err: positional argument 4, :param double result_re.val: positional argument 5, :param double result_re.err: positional argument 6) 
    :return: result 

.. py:function:: sf_psi_int_e(n [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_psi_int_e`
    c code signature: int gsl_sf_psi_int_e(const int n, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il__Rl__Ord`
    
    :param int n: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_psi_1_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_psi_1_e`
    c code signature: int gsl_sf_psi_1_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_psi_1piy(y [, ret])

    Wrapper for :c:func:`gsl_sf_psi_1piy`
    c code signature: double gsl_sf_psi_1piy(const double y)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double y: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_psi_1_int_e(n [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_psi_1_int_e`
    c code signature: int gsl_sf_psi_1_int_e(const int n, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il__Rl__Ord`
    
    :param int n: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_psi_int(n [, ret])

    Wrapper for :c:func:`gsl_sf_psi_int`
    c code signature: double gsl_sf_psi_int(const int n)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il__Rd__O`
    
    :param int n: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_psi_n_e(n, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_psi_n_e`
    c code signature: int gsl_sf_psi_n_e(const int n, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rl__Ord`
    
    :param int n: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_psi_1(x [, ret])

    Wrapper for :c:func:`gsl_sf_psi_1`
    c code signature: double gsl_sf_psi_1(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_psi(x [, ret])

    Wrapper for :c:func:`gsl_sf_psi`
    c code signature: double gsl_sf_psi(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_psi_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_psi_e`
    c code signature: int gsl_sf_psi_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_psi_1piy_e(y [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_psi_1piy_e`
    c code signature: int gsl_sf_psi_1piy_e(const double y, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double y: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

